Function glue::combinators::matchers::isnt

source ·
pub fn isnt<'a, Par>(parser: Par) -> impl Parser<'a, &'a str>
where Par: MatchParser,
Match negatively using a string or character literal, callback or implementation of MatchParser.

The same as is but with the test negated.

Can be used to match from a list of characters:

assert!(isnt(one_of("xyz")).test("foobar"));
// Or:
assert!(isnt("xyz".chars()).test("foobar"));

A function that takes a character as input:

assert!(isnt(numeric).test("foobar"));

A character literal:

assert!(isnt('z').test("foobar"));

A string literal:

assert!(isnt("boofar").test("foobar"));