Function glue::combinators::finders::find_all
source · pub fn find_all<'a, Res, Par>(parser: Par) -> impl Parser<'a, Res>where
Par: SequenceParser<'a, Res>,Expand description
Run each of the provided parsers and in the specified order and return all of the results.
assert_eq!(find_all((is("foo"), is("bar"))).parse("foobar"), Ok((
ParserContext {
input: "foobar",
bounds: 0..6,
},
("foo", "bar"),
)));