Function glue::combinators::takers::take_all
source · pub fn take_all<'a, Res, Par>(parser: Par) -> impl Parser<'a, &'a str>where
Par: SequenceParser<'a, Res>,Expand description
Run each of the provided parsers and in the specified order and return all of the matched input.
assert_eq!(
take_all((is("foo"), is("bar"))).parse("foobar"),
Ok((
ParserContext {
input: "foobar",
bounds: 0..6,
},
"foobar"
))
);